# SCANNER

This is a simple example package. You can use
[GitHub-flavored Markdown](https://guides.github.com/features/mastering-markdown/)
to write your content.

## LICENSE
SCANNER is freely available for non-commercial use.